==> KoGaMa.py-Rewrite-0.5.3.tar.gz: KoGaMa.py-Rewrite-0.5.3/README.md <==
# KoGaMa.py-Rewrite

[![Python Version](https://img.shields.io/badge/python-%E2%89%A53.8-yellow.svg)](https://www.python.org/downloads/)  [![Pypi](https://img.shields.io/pypi/v/KoGaMa.py-Rewrite)](https://pypi.org/project/KoGaMa.py-Rewrite/)  ![MIT license](https://img.shields.io/badge/License-MIT-blue.svg)  [![Downloads](https://static.pepy.tech/badge/KoGaMa.py-Rewrite)](https://static.pepy.tech/badge/KoGaMa.py-Rewrite)  

  **KoGaMa.py-Rewrite, an easy to use API-wrapper for KoGaMa.**


# About

* KoGaMa.py-Rewrite is an API-Wrapper for KoGaMa, an Online Game, re-written in Python 3.8+. The Original Version was: [KoGaMa.py](https://github.com/Ars3ne/kogama.py), made by Ars3ne.

* With this package, you can create your own projects, like Anti-Spams Bots or even Auto-Moderator Bot!

* If you use this Package to create project which violates KoGaMa's [Terms of Use](https://www.kogama.com/help/terms-and-conditions/), your account will most likely get banned. Some features can also be disabled without previous warnings, in order to prevent user abuse.

* In case you've been banned for Innapropiated or Bad Use of this package, we have no responsability. (You've been warned!)

* Note: Versions bellow 0.5 might not work properly.. We recommend you always installing newer versions.
----------------------------------------------------------------------------------------------
# Installation:
  * In order to install this library, run the following command:
Windows:
```
# Windows
pip install KoGaMa.py-Rewrite
```
Unix/macOS:
```
# Unix/macOS
python3 -m pip install "KoGaMa.py-Rewrite"
```
----------------------------------------------------------------------------------------------
## Key Features:
- Easy to Use.
- Alot of Features.
- 1 Dependency (Requests.)

## Example:
```python
from Kogama.kogama import KoGaMa

client = KoGaMa("www") # Change "www" to your server.
client.Login("Admin", "MySecretPassword") # Makes login in our account..
client.PostFeed("12345678", "Hello, I'm using KoGaMa.py-Rewrite") # Posts a message in our Feed.
client.run() # Keeps the account alive.
```
-----

## Credits:
- Tokeeto :: Helped me sending requests to the server & debbuging.
- MD :: Debbuging Code.
- Junko :: Debbuging Code.

## Documentation:
 * [Official Documentation.](https://thenoobpro44.gitbook.io/kogama-py-rewrite/)

*PS: If you have any trouble using the Package contact me on Discord: **TheNoobPro44#2525**.*

==> KoGaMa.py-Rewrite-0.5.4.tar.gz: KoGaMa.py-Rewrite-0.5.4/README.md <==
# KoGaMa.py-Rewrite

[![Python Version](https://img.shields.io/badge/python-%E2%89%A53.8-yellow.svg)](https://www.python.org/downloads/)  [![Pypi](https://img.shields.io/pypi/v/KoGaMa.py-Rewrite)](https://pypi.org/project/KoGaMa.py-Rewrite/)  ![MIT license](https://img.shields.io/badge/License-MIT-blue.svg)  [![Downloads](https://static.pepy.tech/badge/KoGaMa.py-Rewrite)](https://static.pepy.tech/badge/KoGaMa.py-Rewrite)  

  **KoGaMa.py-Rewrite, an easy to use API-wrapper for KoGaMa.**


# About

* KoGaMa.py-Rewrite is an API-Wrapper for KoGaMa, an Online Game, re-written in Python 3.8+. The Original Version was: [KoGaMa.py](https://github.com/Ars3ne/kogama.py), made by Ars3ne.

* With this package, you can create your own projects, like Anti-Spams Bots or even Auto-Moderator Bot!

* If you use this Package to create project which violates KoGaMa's [Terms of Use](https://www.kogama.com/help/terms-and-conditions/), your account will most likely get banned. Some features can also be disabled without previous warnings, in order to prevent user abuse.

* In case you've been banned for Innapropiated or Bad Use of this package, we have no responsability. (You've been warned!)

* Note: Versions bellow 0.5 might not work properly.. We recommend you always installing newer versions.
----------------------------------------------------------------------------------------------
# Installation:
  * In order to install this library, run the following command:
Windows:
```
# Windows
pip install KoGaMa.py-Rewrite
```
Unix/macOS:
```
# Unix/macOS
python3 -m pip install "KoGaMa.py-Rewrite"
```
----------------------------------------------------------------------------------------------
## Key Features:
- Easy to Use & Learn.
- Many Features!
- No Dependencies!

## Example:
```python
from Kogama.kogama import KoGaMa

client = KoGaMa("www") # Change "www" to your server.
client.Login("Admin", "MySecretPassword") # Makes login in our account..
client.PostFeed("12345678", "Hello, I'm using KoGaMa.py-Rewrite") # Posts a message in our Feed.
client.run() # Keeps the account alive.
```
-----

## Credits:
- Tokeeto :: Helping me with Requests & Debbuging Code.
- MD :: Debbuging Code.
- Junko :: Debbuging Code.

## Documentation:
 * [Official Documentation.](https://thenoobpro44.gitbook.io/kogama-py-rewrite/)

*PS: If you have any trouble using the Package contact me on Discord: **TheNoobPro44#2525**.*
